@@ -108,7 +108,7 @@ int guesstype(int n)
       return v<0 ? Ggen: vartype(ctxstack[v]);
     }
   case Ffunction:
-    if (!strcmp(entryname(n),"length"))
+    if (tree[n].x == OPlength)
       return Glg;
   default: /*FALL THROUGH*/
     return Ggen;
@@ -679,7 +679,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
       newdecl((1<<Cauto)|(1<<Cconst),Gempty,-1,&vdiv);
       newdecl((1<<Cauto)|(1<<Cconst),Gempty,-1,&vlen);
       bseq=addseqright(bseq,geninsertvar(arg[0],vdiv));
-      bseq=addseqright(bseq,geninsertvar(newcall("length",vdiv),vlen));
+      bseq=addseqright(bseq,geninsertvar(newopcall(OPlength,vdiv,-1),vlen));
       genblock(bseq,-1);
       savx=s_ctx.n;
       bl1=newblock();
@@ -722,7 +722,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
       div=newcall("divisors", factored ?
           newnode(Flistarg, arg[0], newsmall(1)) : arg[0]);
       bseq=addseqright(bseq,geninsertvar(div,vdiv));
-      bseq=addseqright(bseq,geninsertvar(newcall("length",vdiv),vlen));
+      bseq=addseqright(bseq,geninsertvar(newopcall(OPlength,vdiv,-1),vlen));
       genblock(bseq,-1);
       savx=s_ctx.n;
       bl1=newblock();
@@ -771,7 +771,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
         isvec=1; dosign=1;
         newdecl((1<<Cauto)|(1<<Cconst),Gsmall,-1,&vindex);
         newdecl((1<<Cauto)|(1<<Cconst),Gsmall,-1,&lstep);
-        bseq=addseqright(bseq,geninsertvar(newcall("length",newleaf(vstep)),newleaf(lstep)));
+        bseq=addseqright(bseq,geninsertvar(newopcall(OPlength,newleaf(vstep),-1),newleaf(lstep)));
         sarg[0] = newnode1(Fassign,newleaf(vindex),newsmall(1));
         sarg[1] = newleaf(lstep);
         sarg[2] = newnode(Fmatcoeff,newleaf(vstep),
@@ -984,7 +984,7 @@ void genblockfuncspec(int n, int p, gpfunc *gp)
             newnode(Ftag,
               newcoeff(newleaf(vdiv),newleaf(vloop),-1),Gint)),seq);
       arg[0]=newnode1(Fassign,vloop,newsmall(1));
-      arg[1]=newopcall(OPle,newleaf(vloop),newcall("length",vdiv));
+      arg[1]=newopcall(OPle,newleaf(vloop),newopcall(OPlength,vdiv,-1));
       arg[2]=seq;
       arg[3]=newopcall(OPpp,newleaf(vloop),-1);
       aseq=newnode(tree[n].f,newentry("for"),stacktoargs(arg,4));
