@@ -512,7 +512,7 @@ void genblockmatrixl(int n, int x, int y)
   newdecl((1<<Cconst),Glg,-1,&vsup);
   newdecl(0,Gvec,-1,&ret);
   newdecl(0,Gsmall,-1,&var);
-  bsup=newcall("length",newnode(Ftag,newleaf(vx),Gvec));
+  bsup=newopcall(OPlength,newnode(Ftag,newleaf(vx),Gvec),-1);
   bseq=addseqright(bseq,geninsertvar(x,vx));
   bseq=addseqright(bseq,geninsertvar(y,vy));
   bseq=addseqright(bseq,geninsertvar(bsup,vsup));
@@ -542,7 +542,7 @@ void genblockaffmatrixl(int n, int x, int y, int z)
   newdecl((1<<Cconst),Gsmall,-1,&vy);
   newdecl((1<<Cconst),Glg,-1,&vsup);
   newdecl(0,Gsmall,-1,&var);
-  bsup=newcall("length",newnode(Ftag,newleaf(x),Gvec));
+  bsup=newopcall(OPlength,newnode(Ftag,newleaf(x),Gvec),-1);
   if (tree[z].f==Fentry)
   {
     genblock(z,n);
@@ -940,6 +940,11 @@ void genblock(int n, int p)
       tree[n].f=Ffunction;
     }
   case Ffunction:/*fall through*/
+    if (FC_translength>=0 && x==OPlength && tree[y].f==Ffunction && tree[y].x==OPtrans)
+    {
+      int z=newcall("#_~", tree[y].y);
+      tree[n] = tree[z];
+    }
     if (x==OPtrans && tree[y].f==Fvec)
     {
       if (tree[y].x==-1)
