@@ -736,12 +736,15 @@ void genwrapper(FILE *fout, int nf, int wrap)
   fprintf(fout,"\nwrap_%s(void * _cargs",gp->proto.cname);
   genprotoargs(fout, wrap, 1, nb, stack);
   fprintf(fout,")\n{\n");
+  indent++;
   if (nbc || has_prec)
-    fprintf(fout,"  GEN _args = (GEN) _cargs;\n  ");
-  else
-    fprintf(fout,"  (void) _cargs;\n  ");
+  {
+    genindent(fout);
+    fprintf(fout,"GEN _args = (GEN) _cargs;\n");
+  }
   res  = pushvar(newnode(Fentry, newentry("_res"), -1), 0, t, -1);
   vres = ctxstack+res;
+  genindent(fout);
   if (ctype[t]==ctype[Gvoid])
     fprintf(fout,"(void) ");
   else
@@ -774,7 +777,13 @@ void genwrapper(FILE *fout, int nf, int wrap)
   }
   if (par)
     fputc(')',fout);
-  fprintf(fout,");\n  ");
+  fprintf(fout,");\n");
+  if (!(nbc || has_prec))
+  {
+    genindent(fout);
+    fprintf(fout,"(void) _cargs;\n");
+  }
+  genindent(fout);
   rule = descfindrules(1, &vres->node, wr);
   if (rule)
   {
@@ -788,6 +797,7 @@ void genwrapper(FILE *fout, int nf, int wrap)
     }
   }
   fprintf(fout,"}\n\n");
+  indent--;
   s_ctx.n=savc;
 }
 
