@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2002-2005  The PARI group.
+Copyright (C) 2002-2013  The PARI group.
 
 This file is part of the GP2C package.
 
@@ -10,7 +10,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/
 
 #include "config.h"
 #include <stdlib.h>
@@ -18,7 +18,6 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 #include <string.h>
 #include "header.h"
 static int currblo;
-typedef enum {left,right} side;
 
 void destroynode(int p, side s)
 {
@@ -95,6 +94,7 @@ void moveblock(int n, int p, int ps, int *r, int *rs)
     s=right;z=n;
     moveblock(y,n,right,&z,&s);
     break;
+  case Findarg:
   case Frefarg:
   case Ftag:
     moveblock(x,n,left,r,rs);
@@ -243,6 +243,7 @@ void cleanvar(int n)
       }
     }
     break;
+  case Findarg:
   case Frefarg:
   case Ftag:
     cleanvar(x);
@@ -341,6 +342,7 @@ void cleancode(int n, int p, int d)
         destroynode(p,d);
     }
     break;
+  case Findarg:
   case Frefarg:
   case Ftag:
     cleancode(x,n,left);
@@ -395,6 +397,7 @@ void gendeblock(int n, int p, int ps, int *r, int *rs)
       s=right;z=n;
       gendeblock(y,n,right,&z,&s);
       break;
+    case Findarg:
     case Frefarg:
     case Ftag:
       gendeblock(x,n,left,r,rs);
