@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2002-2003  The PARI group.
+Copyright (C) 2002-2013  The PARI group.
 
 This file is part of the GP2C package.
 
@@ -10,7 +10,7 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/
 
 #include "config.h"
 #include <stdlib.h>
@@ -22,7 +22,7 @@ Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 static int toplevel=0;
 int initnode=0;
 
-const char *basename(const char *s)
+static const char *basename(const char *s)
 {
   long i;
   long l=strlen(s);
@@ -96,11 +96,8 @@ void genpredeclaration(int args, int n)
   }
 }
 
-/*
-  n: node
-  p:parent node
-*/
-void gentoplevel(int n, int p)
+/* n: node */
+void gentoplevel(int n)
 {
   int x,y;
   if (n<0)
@@ -112,32 +109,34 @@ void gentoplevel(int n, int p)
   case Fseq:
     if (x>=0 && tree[x].f!=Fdeffunc && tree[x].f!=Fseq)
     {
-      if (isfunc(x,"global"))
-        genpredeclaration(tree[x].y,x);
-      if (isfunc(x,"local"))
-        warning(x,"`local' at top-level discarded");
+      int dx = detag(x);
+      if (isfunc(dx,"global"))
+        genpredeclaration(tree[dx].y,dx);
+      if (isfunc(dx,"local"))
+        warning(dx,"`local' at top-level discarded");
       else
         toplevel=addseqright(toplevel,x);
       tree[n].x=GNIL;
     }
     else
-      gentoplevel(x,n);
-    if (y>=0 && tree[y].f!=Fdeffunc)
+      gentoplevel(x);
+    if (y>=0 && tree[y].f!=Fdeffunc && tree[y].f!=Fseq)
     {
-      if (isfunc(y,"global"))
-        genpredeclaration(tree[y].y,y);
-      if (isfunc(y,"local"))
-        warning(y,"`local' at top-level discarded");
+      int dy = detag(y);
+      if (isfunc(dy,"global"))
+        genpredeclaration(tree[dy].y,dy);
+      if (isfunc(dy,"local"))
+        warning(dy,"`local' at top-level discarded");
       else
         toplevel=addseqright(toplevel,y);
       tree[n].y=GNIL;
     }
     else
-      gentoplevel(y,n);
+      gentoplevel(y);
     break;
   case Ffunction:
     die(n,"Ffunction in toplevel");
-    gentoplevel(y,n);
+    gentoplevel(y);
     break;
   case Fdeffunc:
   case Fentry:
@@ -145,10 +144,11 @@ void gentoplevel(int n, int p)
   case Fsmall:
   case Fnoarg:
     break;
+  case Findarg:
   case Frefarg:
   case Ftag:
     die(n,"%s in toplevel",funcname(tree[n].f));
-    gentoplevel(x,n);
+    gentoplevel(x);
     break;
   default:
     if (tree[n].f>=FneedENTRY)
@@ -157,8 +157,8 @@ void gentoplevel(int n, int p)
     }
     else
     {
-      gentoplevel(x,n);
-      gentoplevel(y,n);
+      gentoplevel(x);
+      gentoplevel(y);
     }
   }
 }
