@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2000-2005  The PARI group.
+Copyright (C) 2000-2013  The PARI group.
 
 This file is part of the GP2C package.
 
@@ -10,10 +10,10 @@ ANY WARRANTY WHATSOEVER.
 
 Check the License for details. You should have received a copy of it, along
 with the package; see the file 'COPYING'. If not, write to the Free Software
-Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/
 
-int **typemax;
-int *ctype;
+extern int **typemax;
+extern int *ctype;
 static inline int is_subtype(int a, int b) {return typemax[a][b]==b;}
 
 /*Mode:
@@ -33,10 +33,10 @@ static inline int is_subtype(int a, int b) {return typemax[a][b]==b;}
 #define MODHERIT ((1<<Mvar)|(1<<Msidef)|(1<<Mterm)|(1<<Mprec))
 typedef enum {Mvar, Msidef, Mterm, Mprec, Msemicolon, Mparens, Mbrace, Melse, Mcopy, Msimple, Muntil} Menum;
 
-typedef enum {Gempty, Gvoid, Gnegbool, Gbool, Gsmall_int, Gsmall, Gint, Greal, Glg, Gvecsmall, Gvec, Gvar, Ggen, Ggenstr, Gstr, Gclosure, Gfunc_GG, Gnotype} Genum;
+typedef enum {Gempty, Gvoid, Gnegbool, Gbool, Gsmall_int, Gusmall, Gsmall, Gint, Greal, Glg, Gvecsmall, Gvec, Gvar, Ggen, Ggenstr, Gstr, Gclosure, Gfunc_GG, Gnotype} Genum;
 
 #ifdef TYPE
 const char *Mneeded[]={"var","sidef","term","prec","semicolon","parens","brace","else","copy","simple",NULL};
 
-const char *GPneeded[]={"empty","void","negbool","bool","small_int","small","int","real","lg","vecsmall","vec","var","gen","genstr","str","closure","func_GG","notype",NULL};
+const char *GPneeded[]={"empty","void","negbool","bool","small_int","usmall","small","int","real","lg","vecsmall","vec","var","gen","genstr","str","closure","func_GG","notype",NULL};
 #endif
